@@ -103,7 +103,7 @@ fn resolve_pypi_cred(
     }
 
     if let Some((username, password)) =
-        registry_name.and_then(|name| load_pypi_cred_from_config(&config, name))
+        registry_name.and_then(|name| load_pypi_cred_from_config(config, name))
     {
         println!("🔐 Using credential in pypirc for upload");
         return (username, password);
@@ -416,12 +416,12 @@ fn pep517(subcommand: Pep517Command) -> Result<()> {
 /// Handles authentication/keyring integration and retrying of the publish subcommand
 #[cfg(feature = "upload")]
 fn upload_ui(items: &[PathBuf], publish: &PublishOpt) -> Result<()> {
-    let registry = complete_registry(&publish)?;
+    let registry = complete_registry(publish)?;
 
     println!("🚀 Uploading {} packages", items.len());
 
     for i in items {
-        let upload_result = upload(&registry, &i);
+        let upload_result = upload(&registry, i);
 
         match upload_result {
             Ok(()) => (),
@@ -514,7 +514,7 @@ fn run() -> Result<()> {
             let build_context = build.into_build_context(!debug, !no_strip)?;
 
             if !build_context.release {
-                eprintln!("⚠  Warning: You're publishing debug wheels");
+                eprintln!("⚠️  Warning: You're publishing debug wheels");
             }
 
             let mut wheels = build_context.build_wheels()?;
@@ -608,7 +608,7 @@ fn run() -> Result<()> {
         #[cfg(feature = "upload")]
         Opt::Upload { publish, files } => {
             if files.is_empty() {
-                println!("⚠  Warning: No files given, exiting.");
+                println!("⚠️  Warning: No files given, exiting.");
                 return Ok(());
             }
 
