@@ -1,4 +1,4 @@
-use crate::auditwheel::Manylinux;
+use crate::auditwheel::PlatformTag;
 use crate::{BridgeModel, Target};
 use anyhow::{bail, format_err, Context, Result};
 use regex::Regex;
@@ -7,7 +7,7 @@ use std::collections::HashSet;
 use std::fmt;
 use std::io;
 use std::path::{Path, PathBuf};
-use std::process::{Command, Stdio};
+use std::process::Command;
 use std::str;
 
 /// This snippets will give us information about the python interpreter's
@@ -156,7 +156,7 @@ fn find_all_windows(target: &Target, min_python_minor: usize) -> Result<Vec<Stri
         let re = Regex::new(r"^([^#].*?)[\s*]+([\w\\:.-]+)\s*$").unwrap();
         let mut paths = vec![];
         for i in lines {
-            if let Some(capture) = re.captures(&i) {
+            if let Some(capture) = re.captures(i) {
                 if &capture[1] == "base" {
                     continue;
                 }
@@ -339,10 +339,10 @@ impl PythonInterpreter {
     /// Don't ask me why or how, this is just what setuptools uses so I'm also going to use
     ///
     /// If abi3 is true, cpython wheels use the generic abi3 with the given version as minimum
-    pub fn get_tag(&self, manylinux: &Manylinux, universal2: bool) -> String {
+    pub fn get_tag(&self, platform_tag: PlatformTag, universal2: bool) -> String {
         match self.interpreter_kind {
             InterpreterKind::CPython => {
-                let platform = self.target.get_platform_tag(manylinux, universal2);
+                let platform = self.target.get_platform_tag(platform_tag, universal2);
                 if self.target.is_unix() {
                     format!(
                         "cp{major}{minor}-cp{major}{minor}{abiflags}-{platform}",
@@ -362,7 +362,7 @@ impl PythonInterpreter {
                 }
             }
             InterpreterKind::PyPy => {
-                let platform = self.target.get_platform_tag(manylinux, universal2);
+                let platform = self.target.get_platform_tag(platform_tag, universal2);
                 // pypy uses its version as part of the ABI, e.g.
                 // pypy 3.7 7.3 => numpy-1.20.1-pp37-pypy37_pp73-manylinux2010_x86_64.whl
                 format!(
@@ -414,7 +414,6 @@ impl PythonInterpreter {
     ) -> Result<Option<PythonInterpreter>> {
         let output = Command::new(&executable.as_ref())
             .args(&["-c", GET_INTERPRETER_METADATA])
-            .stderr(Stdio::inherit())
             .output();
 
         let err_msg = format!(
@@ -426,7 +425,20 @@ impl PythonInterpreter {
                 if output.status.success() {
                     output
                 } else {
-                    bail!(err_msg);
+                    let stderr = str::from_utf8(&output.stderr).unwrap();
+                    if stderr.starts_with(&format!(
+                        "pyenv: {}: command not found",
+                        executable.as_ref().display()
+                    )) {
+                        eprintln!(
+                            "⚠️  Warning: skipped unavailable python interpreter '{}' from pyenv",
+                            executable.as_ref().display()
+                        );
+                        return Ok(None);
+                    } else {
+                        eprintln!("{}", stderr);
+                        bail!(err_msg);
+                    }
                 }
             }
             Err(err) => {
@@ -454,7 +466,7 @@ impl PythonInterpreter {
             }
         };
 
-        let abiflags = fun_with_abiflags(&message, &target, &bridge).context(format_err!(
+        let abiflags = fun_with_abiflags(&message, target, bridge).context(format_err!(
             "Failed to get information from the python interpreter at {}",
             executable.as_ref().display()
         ))?;
@@ -483,7 +495,7 @@ impl PythonInterpreter {
     ) -> Result<Vec<PythonInterpreter>> {
         let min_python_minor = min_python_minor.unwrap_or(MINIMUM_PYTHON_MINOR);
         let executables = if target.is_windows() {
-            find_all_windows(&target, min_python_minor)?
+            find_all_windows(target, min_python_minor)?
         } else {
             (min_python_minor..MAXIMUM_PYTHON_MINOR)
                 .map(|minor| format!("python3.{}", minor))
@@ -491,8 +503,7 @@ impl PythonInterpreter {
         };
         let mut available_versions = Vec::new();
         for executable in executables {
-            if let Some(version) =
-                PythonInterpreter::check_executable(&executable, &target, &bridge)?
+            if let Some(version) = PythonInterpreter::check_executable(&executable, target, bridge)?
             {
                 available_versions.push(version);
             }
@@ -511,11 +522,11 @@ impl PythonInterpreter {
     ) -> Result<Vec<PythonInterpreter>> {
         let mut available_versions = Vec::new();
         for executable in executables {
-            if let Some(version) =
-                PythonInterpreter::check_executable(executable, &target, &bridge).context(
-                    format!("{} is not a valid python interpreter", executable.display()),
-                )?
-            {
+            if let Some(version) = PythonInterpreter::check_executable(executable, target, bridge)
+                .context(format!(
+                "{} is not a valid python interpreter",
+                executable.display()
+            ))? {
                 available_versions.push(version);
             } else {
                 bail!(
